@@ -927,17 +927,17 @@ class DSLibrary(object):
             # this method will be used to open the stream...
             use_opener = self.open_run_data if open_args.pop("run_data", None) else self.open_resource
         elif hasattr(resource_name, "read"):
-            stream = resource_name
-            orig_mode = "r" if isinstance(stream, io.TextIOBase) else "rb"
+            ex_stream = resource_name
+            orig_mode = "r" if isinstance(ex_stream, io.TextIOBase) else "rb"
             count = [0]
             def open_existing_stream(filename: str, mode: str='rb', **kwargs):
                 if count[0]:
-                    if hasattr(stream, "seek") and hasattr(stream, "seekable") and stream.seekable():
-                        stream.seek(0)
+                    if hasattr(ex_stream, "seek") and hasattr(ex_stream, "seekable") and ex_stream.seekable():
+                        ex_stream.seek(0)
                     else:
                         raise Exception("internal usage error, stream is not seekable")
                 count[0] += 1
-                s_out = GenericStreamWrapper(stream, close=False)
+                s_out = GenericStreamWrapper(ex_stream, close=False)
                 if mode != orig_mode:
                     if mode == 'r':
                         s_out = io.TextIOWrapper(s_out, 'utf-8')
